@@ -30,14 +30,13 @@ getFont fontStyle c
  
 fontsetter :: Font -> [Char]
 fontsetter f
-  = if os == "linux" then
-      "\\setmainfont" ++ inner ++ "\\setmonofont" ++ innermono else ""
+  =  "\\setmainfont" ++ inner ++ "\\setmonofont" ++ innermono 
   where filename
           = reverse ((takeWhile (/= '/')) (reverse (getttf f)))
         pathname = reverse ((dropWhile (/= '/')) (reverse (getttf f)))
-        inner = "[Path=" ++ pathname ++ (mid f) ++ "]{" ++ filename ++ "}"
+        inner = "[" ++ (if os=="linux" then "Path=" ++ pathname else "") ++ (mid f) ++ "]{" ++ filename ++ "}"
         innermono
-          = "[Path=" ++ pathname ++ (midmono f) ++ "]{" ++ filename ++ "}"
+          = "[" ++(if os=="linux" then "Path=" ++ pathname else "")++ (midmono f) ++ "]{" ++ filename ++ "}"
         mid i
           | i `elem`
               [ComputerModernRoman, ComputerModernRomanBold,
