@@ -57,14 +57,15 @@ myplus x y = x{edits = (edits x) + (edits y)}
 contribsum :: [Map String Contributor] -> Map String Contributor
 contribsum x = Data.List.foldl (unionWith myplus) Data.Map.empty x
  
-imperativeStateZero :: ImperativeState
+imperativeStateZero :: IO ImperativeState
 imperativeStateZero
-  = ImperativeState{audict = [], fullUrl = fullWikiUrlZero,
-                    tmpPath = ""}
+  = do v<-newMVar (0::Int)
+       return ImperativeState{audict = [], fullUrl = fullWikiUrlZero,
+                    tmpPath = "" ,counter=v}
  
 data ImperativeState = ImperativeState{audict ::
                                        [MVar (Map String Contributor)],
-                                       fullUrl :: FullWikiUrl, tmpPath :: String}
+                                       fullUrl :: FullWikiUrl, tmpPath :: String, counter::MVar Int}
 
 data ImageInfo = ImageInfo{wikiFilename :: String,imageNumber::Integer,contributorUrls::[String],descriptionUrl::URL}
 
