@@ -14,6 +14,11 @@ licenses = minlicenses ++ (map go minlicenses)
 minlicenses :: [(String, String)]
 minlicenses
   = [("http://en.wikipedia.org/wiki/public_domain", "PD"),
+     ("https://en.wikipedia.org/wiki/Public_domain", "PD"),
+     ("https://de.wikibooks.org/wiki/GNU_Freie_Dokumentationslizenz", "GFDL"),
+     ("https://de.wikipedia.org/wiki/GNU-Lizenz_f%C3%BCr_freie_Dokumentation", "GFDL"),
+     ("https://de.wikipedia.org/wiki/GNU-Lizenz_für_freie_Dokumentation", "GFDL"),
+
      ("http://en.wikipedia.org/wiki/en:GNU_Free_Documentation_License",
       "GFDL"),
      ("http://en.wikipedia.org/wiki/en:GNU_General_Public_License",
@@ -45,6 +50,8 @@ minlicenses
       "CC-BY-SA-3.0"),
      ("http://creativecommons.org/licenses/by-sa/3.0/deed.de",
       "CC-BY-SA-3.0"),
+     ("https://creativecommons.org/licenses/by-sa/3.0/deed.de",
+      "CC-BY-SA-3.0"),
      ("http://creativecommons.org/licenses/by-sa/3.0/cr/deed.en",
       "CC-BY-SA-3.0"),
      ("http://creativecommons.org/licenses/by-sa/3.0/de/deed.en",
