@@ -518,7 +518,7 @@ removePrintVersion lem
   = fun
       ["/Druckversion","/ Druckversion","/Print version", "/Complete Wikibook", "/All Chapters",
        "/Print Version", "/print version", "/Printable version",
-       "/The Whole Book"]
+       "/The Whole Book", "/print"]
       lem
   where fun (y : ys) x
           = case splitOn y x of
@@ -579,6 +579,7 @@ chartrans '\\' = "\\textbackslash{}"
 chartrans '<' = "<{}"
 chartrans '>' = ">{}"
 chartrans '-' = "-{}"
+chartrans ' ' = "\\,"
 chartrans c = c : []
  
 {-DHUN| Character escaping from Unicode to web links inside latex with the URL package DHUN-}
