@@ -6,8 +6,8 @@ import Control.DeepSeq
  
 {-DHUN| takes a function of return type IO which takes on parameter and an MVar containing at the same type as the parameter of the function and returns and IO action containing an MVar containing the same type as the tyoe contained in the IO Action returned by the function. This function retuns immediately and passed an empty MVar as return type. As soon as the MVar containing the same type as the parameter of the function is ready for reading the the function is executed in a new thread. As soon as the function return a value, the it is written into the returned MVar.  DHUN-}
  
-(<$>) :: MVar Int -> (a -> IO b) -> MVar a -> IO (MVar b)
-(<$>) vv f x
+(<$$>) :: MVar Int -> (a -> IO b) -> MVar a -> IO (MVar b)
+(<$$>) vv f x
   = do var <- newEmptyMVar
        _ <- myFork vv (go var)
        return var
@@ -19,12 +19,12 @@ import Control.DeepSeq
 {-DHUN| takes a value and returns an IO action that contain a filled MVar conatining the value DHUN-}
  
 base :: MVar Int -> a -> IO (MVar a)
-base v x = ((pure v). return) x  
+base v x = ((ppure v). return) x  
  
 {-DHUN| takes an IO action and return an MVar containing the and IO action the returns an MVar containing the same type as contained by the IO action passed to this function. The IO action passed as first parameter to this function is executed in a new thread. As soon as it finishes its result is written into the returned MVar DHUN-}
  
-pure :: MVar Int ->  IO a -> IO (MVar a)
-pure vv x
+ppure :: MVar Int ->  IO a -> IO (MVar a)
+ppure vv x
   = do var <- newEmptyMVar
        _ <- myFork vv (go var)
        return var
@@ -73,7 +73,7 @@ liftList2 vv f x
 {-DHUN| prefix version of the angle bracked dollar operator described above DHUN-}
  
 liftA :: MVar Int ->  (a -> IO b) -> MVar a -> IO (MVar b)
-liftA v f x = (<$>) v f x
+liftA v f x = (<$$>) v f x
  
 {-DHUN| same as liftA. Just function must have exactly two parameter instead of only one DHUN-}
  
