@@ -84,7 +84,7 @@ instance NFData ProgressInfo
  
 serve :: Int -> IO ()
 serve p = do a<-newMVar Data.Map.Strict.empty
-             simpleHTTP nullConf{port = p, timeout = 100000}  $ msum [dirs "progress" $ path $ \subject -> progressBar a subject, dirs "file" $ path $ \subject -> fileFrame a subject, formPage a]
+             simpleHTTP nullConf{port = p, timeout = 100000}  $ msum [dirs "progress" $ path $ \subject -> progressBar a subject, dirs "file" $ path $ \subject -> fileFrame a subject, dirs "fill" $ path $ \subject -> formPage a subject, formPage a ""]
 
 
 
@@ -177,8 +177,8 @@ wwidth2 :: [Char]
 wwidth2="width:400px"
 wwidth :: AttributeValue
 wwidth=stringValue wwidth2
-formPage :: MVar (Map Int ProgressInfo) -> ServerPart Response
-formPage m
+formPage :: MVar (Map Int ProgressInfo) -> String -> ServerPart Response
+formPage m s
   = do decodeBody (defaultBodyPolicy "/tmp/" 0 1000000 1000000)
        msum [viewForm, processForm]
   where  
@@ -200,7 +200,7 @@ formPage m
                           do H.tr $
                                do H.td "URL to the Wiki to be converted"
                                   H.td $
-                                    do H.input H.! A.style wwidth H.! A.type_ "text" H.! A.id "msg" H.! A.name "msg"
+                                    do H.input H.! A.style wwidth H.! A.type_ "text" H.! A.id "msg" H.! A.name "msg" H.! A.value (stringValue s)
                              H.tr $
                                do H.td "Output Format"
                                   H.td $ do
@@ -275,6 +275,7 @@ formPage m
 ex :: ProcessHandle -> Handle -> Handle -> Double -> MVar (Map Int ProgressInfo)-> Int -> IO ()
 ex h i e t m n
      = do tt<-getPOSIXTime
+          threadDelay 100                  
           if (realToFrac tt) > t 
            then 
             do System.IO.hPutStr i "\n" 
@@ -295,7 +296,11 @@ mylist=[("downloading article and contributor information", 0.02540431143798292)
 
 wwait :: Handle -> IO ()
 wwait h = do b<-hIsEOF h
-             if b then wwait h else return ()
+             if b 
+               then 
+                 do threadDelay 1000
+                    wwait h 
+               else return ()
 
 progressDriver::Int->Handle->MVar (Map Int ProgressInfo)->String->IO ()
 progressDriver n o t s = do xo<-hIsOpen o
