@@ -116,7 +116,7 @@ simpleContributors theLemma theHost uu st
        let y = decodeString yy
        let x = decodeString xx
        let dd
-             = (deepGet "a" "class" "mw-userlink" (parseit minparsers x)) ::
+             = ((deepGet "a" "class" "new mw-userlink" (parseit minparsers x))++(deepGet "a" "class" "mw-userlink" (parseit minparsers x))) ::
                  [Anything Char]
        let ll = (filter pre (map go dd))
        let n = (nub ll) :: [(String, String)]
@@ -126,6 +126,7 @@ simpleContributors theLemma theHost uu st
            Just zz -> return
                         [(fst (treeToLaTeX3 zz initialState{urld = analyseNetloc (hostname . fullUrl $ st)}), "", 1 :: Int, getLicense ht)]
            _ -> return out
+
   where  
         go :: Anything Char -> (String, String)
         go (Environment Tag (TagAttr _ m) l)
