@@ -6,7 +6,8 @@ import Data.List.Split (splitOn)
 import Control.Monad
 import System.IO
 import Data.List.HT (dropWhileRev)
- 
+import System.IO.Strict
+
 {-DHUN| Write a unicode string to a utf8 encoded file. The first parameter is the filename, the second the contend to be written to the file. DHUN-}
  
 writeFile :: FilePath -> String -> IO ()
@@ -22,7 +23,7 @@ readFile :: FilePath -> IO String
 readFile f
   = do h <- openFile f ReadMode
        hSetEncoding h utf8
-       z <- hGetContents h
+       z <- System.IO.Strict.hGetContents h
        return z
  
 {-DHUN| If the list is not empty it returns the list without the last item, otherwise the empty list- DHUN-}
