@@ -82,7 +82,6 @@ geturl u
                         []))
                     req0) {method=method req0}
           res <- (withManager $ httpLbs req)`X.catch` statusExceptionHandler
-          print u
           return ((unpackChars (responseBody res))))
       fun
  where  
@@ -102,7 +101,6 @@ geturl2 u
                         []))
                     req0) {method=method req0}
           res <- (withManager $ httpLbs req)`X.catch` statusExceptionHandler
-          print u
           return (BStr.pack (map (fromIntegral.ord)(unpackChars (responseBody res)))))
       fun
  where  
@@ -114,13 +112,13 @@ geturl2 u
 geturl4 :: String -> String -> IO String
 geturl4 s u
   = if u=="" then return ([]) else Control.Exception.catch
-      (do req0 <- parseUrl (u++"/"++s)
+      (do req1 <- parseUrl (u++"/"++s)
+          let req0 = req1 {queryString=UTF8Str.fromString "",path=if (head.reverse$ s)=='?' then (UTF8Str.fromString.(++"%3F").UTF8Str.toString) (path req1) else path req1}
           let req
                 = ((urlEncodedBody
                      (map (\ (a, b) -> (UTF8Str.fromString a, UTF8Str.fromString b))
                         [("mw-input-pages",s),("curonly","1"),("wpExportTemplates","0"),("wpDownload","1")]))
                     req0) 
-          print u
           res <- (withManager (httpLbs req))`X.catch` statusExceptionHandler
           return ((unpackChars (responseBody res))))
       fun
@@ -144,7 +142,6 @@ geturl3 u d s
                         [("wpInput", d), ("removecomments", "1"), ("removenowiki", "1"),
                          ("generate_xml", "0"), ("contexttitle", s)]))
                     req0
-          print u
           res <- (withManager $ httpLbs req) `X.catch` statusExceptionHandler
           return ((unpackChars (responseBody res))))
       fun
