@@ -114,11 +114,11 @@ wikiLinkLocationesc l st
 getUrlFromWikiLinkInfoesc :: WikiLinkInfo -> String
 getUrlFromWikiLinkInfoesc i
   = case (urldata i) of
-        UrlInfo x -> "http://" ++
+        UrlInfo x -> "https://" ++
                        (language x) ++
                          "." ++
                            (wikitype x) ++ ".org/wiki/" ++ (escapelink (urlEncode (page i)))
-        BaseUrl (WikiBaseUrl x) -> "http://" ++
+        BaseUrl (WikiBaseUrl x) -> "https://" ++
                                      x ++ "/wiki/" ++ (escapelink (urlEncode (page i)))
  
 	{-DHUN| converts a WikiLinkInfo value pointing to a page on a wiki to the full url of that page as string. It is not is escaped in any way, so ready for use in a webbrowers DHUN-}
@@ -126,10 +126,10 @@ getUrlFromWikiLinkInfoesc i
 getUrlFromWikiLinkInfo :: WikiLinkInfo -> String
 getUrlFromWikiLinkInfo i
   = case (urldata i) of
-        UrlInfo x -> "http://" ++
+        UrlInfo x -> "https://" ++
                        (language x) ++
                          "." ++ (wikitype x) ++ ".org/wiki/" ++ (urlEncode (page i))
-        BaseUrl (WikiBaseUrl x) -> "http://" ++
+        BaseUrl (WikiBaseUrl x) -> "https://" ++
                                      x ++ "/wiki/" ++ (urlEncode (page i))
  
 {-DHUN| converts a WikiUrlData value pointing to a wiki and a string (like a part of a url) pointing to a page relative to that wiki and returns the full url of that page as string DHUN-}
@@ -137,9 +137,9 @@ getUrlFromWikiLinkInfo i
 wikiUrlDataToString :: WikiUrlData -> String -> String
 wikiUrlDataToString w i
   = case w of
-        UrlInfo x -> "http://" ++
+        UrlInfo x -> "https://" ++
                        (language x) ++ "." ++ (wikitype x) ++ ".org" ++ i
-        BaseUrl (WikiBaseUrl x) -> "http://" ++ x ++ i
+        BaseUrl (WikiBaseUrl x) -> "https://" ++ x ++ i
  
 {-DHUN| This function takes the contend of a wikilink in wiki markup notation as first input parameter. So for the wiki link (mediawiki markup notation) [[en:JohnDow|John Dow]] this is 'en:JohnDow|John Dow' (the single quotes were added to make the string distinguishable from the text and are not part of the passed parameter). It takes the WikiUrlData value describing the wiki the page currently being processed belongs to as second parameter. It returns a WikiLinkInfo value describing the target of the link given as first parameter when evaluated with respect to the second parameter DHUN-}
  
